@@ -1,9 +1,8 @@
-__version__         = '0.5.1'
-__author__          = "Dave Martorana (http://davemartorana.com), Richard Cooper (http://frozenskys.com), Bill Jones (oraclebill), Dmitry Golomidov (deeGraYve)"
-__date__            = '2010-April-14'
-__url__             = 'http://postmarkapp.com'
-__copyright__       = "(C) 2009-2017 David Martorana, Wildbit LLC, Python Software Foundation."
-
+__version__ = '0.5.2'
+__author__ = "Dave Martorana (http://davemartorana.com), Richard Cooper (http://frozenskys.com), Bill Jones (oraclebill), Dmitry Golomidov (deeGraYve)"
+__date__ = '2010-April-14'
+__url__ = 'http://postmarkapp.com'
+__copyright__ = "(C) 2009-2017 David Martorana, Wildbit LLC, Python Software Foundation."
 __doc__ = '''
 
     PMMail object for Postmark (http://postmarkapp.com)
@@ -16,36 +15,36 @@ __doc__ = '''
         Make sure you have a Postmark account.  Visit
         http://postmarkapp.com to sign up for an account.
         Requires a Postmark API key.
-    
-        Import postmark.PMMail to use Postmark Sending. 
-        Check class documentation on PMMail object for 
+
+        Import postmark.PMMail to use Postmark Sending.
+        Check class documentation on PMMail object for
         more information.
 
-        Import postmark.PMBatchMail object to send batches of 
-        messages. Either pass a "messages" argument or set 
+        Import postmark.PMBatchMail object to send batches of
+        messages. Either pass a "messages" argument or set
         the .messages property of the PMBatchMail object to an
         array of PMMail objects.
-        
-        Import postmark.PMBounceManager to use Postmark Bounce API. 
-        Check class documentation on PMBounceManager object for 
+
+        Import postmark.PMBounceManager to use Postmark Bounce API.
+        Check class documentation on PMBounceManager object for
         more information.
-        
+
     DJANGO:
         The library can be used stand-alone with Django.  You can also
-        add the setting 
-        
+        add the setting
+
         POSTMARK_API_KEY = 'your-key'
         POSTMARK_SENDER = '<From Name> from@emailaddress.com'
         POSTMARK_TEST_MODE = True/False
-        
+
         to your settings.py file, and when you create a new PMMail object,
         it will grab the API key automatically.
-        
+
         Using POSTMARK_TEST_MODE=True will not actually send the email, but
         instead dump the JSON packet that would be sent to Postmarkapp.com.
-        By default this setting is False, and if not specified, will 
+        By default this setting is False, and if not specified, will
         be assumed to be False.
-        
+
         To reroute all Django E-Mail functions like send_mail() and
         mail_admins() through postmark use the following setting:
 
@@ -68,7 +67,7 @@ __doc__ = '''
             422: Unprocessable Entity - usually an exception with either the sender
             not having a matching Sender Signature in Postmark.  Read the message
             details for further information
-    
+
         PMMailServerErrorException(PMMailSendException):
             500: Internal error - this is on the Postmark server side.  Errors are
             logged and recorded at Postmark.
@@ -77,8 +76,13 @@ __doc__ = '''
             A URLError was caught - usually has to do with connectivity
             and the ability to reach the server.  The inner_exception will
             have the base URLError object.
-            
-    TODO: 
+
+        PMMailInactiveRecipientException(PMMailSendException):
+            406: You tried to send a message to a recipient that has been marked as
+            inactive. If this was a batch operation, the rest of the messages were
+            still sent.
+
+    TODO:
         Add automatic multipart emails via regex stripping of HTML tags from html_body
         if the .multipart property is set to True
 
